@@ -6,9 +6,8 @@ test -z "$srcdir" && srcdir=.
 ORIGDIR=`pwd`
 cd $srcdir
 
-intltoolize
+autopoint --force
+AUTOPOINT='intltoolize --automake --copy' autoreconf -v --install --force || exit 1
 
-autoreconf -v --install || exit 1
 cd $ORIGDIR || exit $?
-
 $srcdir/configure --enable-maintainer-mode "$@"
